@@ -21,8 +21,10 @@ from puffotter.env import load_env_file
 from puffotter.flask.initialize import init_flask
 from puffotter.flask.wsgi import start_server
 from fat_ffipd import sentry_dsn, root_path
-from fat_ffipd.bg_tasks import bg_tasks
+from fat_ffipd.background import bg_tasks
 from fat_ffipd.Config import Config
+from fat_ffipd.routes import blueprint_generators
+from fat_ffipd.db import models
 
 
 def main():
@@ -36,7 +38,7 @@ def main():
         sentry_dsn,
         root_path,
         Config,
-        [],
-        []
+        models,
+        blueprint_generators
     )
     start_server(Config, bg_tasks)
